pitchtools.make_n_middle_c_centered_pitches
===========================================

.. autofunction:: abjad.tools.pitchtools.make_n_middle_c_centered_pitches.make_n_middle_c_centered_pitches
   :noindex:
